<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>History</source>
        <translation>History</translation>
    </message>
    <message>
        <source>Chats History</source>
        <translation>Chats History</translation>
    </message>
    <message>
        <source>Save messages in history</source>
        <translation>Save messages in history</translation>
    </message>
    <message>
        <source>Save chats with anonymous users</source>
        <translation>Save chats with anonymous users</translation>
    </message>
    <message>
        <source>Status Changes</source>
        <translation>Status Changes</translation>
    </message>
    <message>
        <source>Save status changes</source>
        <translation>Save status changes</translation>
    </message>
    <message>
        <source>Save status changes in history</source>
        <translation>Save status changes in history</translation>
    </message>
    <message>
        <source>Save status only with description</source>
        <translation>Save status only with description</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Shortcuts</translation>
    </message>
    <message>
        <source>View history</source>
        <translation>View history</translation>
    </message>
    <message>
        <source>Save chats in history</source>
        <translation>Save chats in history</translation>
    </message>
    <message>
        <source>History in chat window</source>
        <translation>History in chat window</translation>
    </message>
    <message>
        <source>Show messages from history since</source>
        <translation>Show messages from history since</translation>
    </message>
    <message>
        <source>Choose time period in which messages can be quoted in chat window</source>
        <translation>Choose time period in which messages can be quoted in chat window</translation>
    </message>
    <message>
        <source>yesterday</source>
        <translation>yesterday</translation>
    </message>
    <message>
        <source>last week</source>
        <translation>last week</translation>
    </message>
    <message>
        <source>last month</source>
        <translation>last month</translation>
    </message>
    <message>
        <source>Limit number of messages from history</source>
        <translation>Limit number of messages from history</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Behavior</translation>
    </message>
    <message>
        <source>Chat window</source>
        <translation>Chat window</translation>
    </message>
</context>
<context>
    <name>BuddyHistoryDeleteHandler</name>
    <message>
        <source>Chat history</source>
        <translation>Chat history</translation>
    </message>
</context>
<context>
    <name>ChatHistoryTab</name>
    <message>
        <source>&amp;Clear Chat History</source>
        <translation>&amp;Clear Chat History</translation>
    </message>
</context>
<context>
    <name>History</name>
    <message>
        <source>Clear History</source>
        <translation>Clear History</translation>
    </message>
</context>
<context>
    <name>HistoryBuddyConfigurationWidget</name>
    <message>
        <source>History</source>
        <translation>History</translation>
    </message>
    <message>
        <source>Store history</source>
        <translation>Store history</translation>
    </message>
</context>
<context>
    <name>HistoryChatConfigurationWidget</name>
    <message>
        <source>History</source>
        <translation>History</translation>
    </message>
    <message>
        <source>Store history</source>
        <translation>Store history</translation>
    </message>
</context>
<context>
    <name>HistoryMessagesTab</name>
    <message>
        <source>&amp;Remove entries</source>
        <translation>&amp;Remove entries</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Do you really want to delete history?</source>
        <translation>Do you really want to delete history?</translation>
    </message>
    <message>
        <source>Delete history</source>
        <translation>Delete history</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
</context>
<context>
    <name>HistoryQueryResultsModel</name>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Length</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Date</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Title</translation>
    </message>
</context>
<context>
    <name>HistoryWindow</name>
    <message>
        <source>History</source>
        <translation>History</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Search</translation>
    </message>
    <message>
        <source>&amp;Clear Status History</source>
        <translation>&amp;Clear Status History</translation>
    </message>
    <message>
        <source>&amp;Clear SMS History</source>
        <translation>&amp;Clear SMS History</translation>
    </message>
    <message>
        <source>Chats</source>
        <translation>Chats</translation>
    </message>
    <message>
        <source>Statuses</source>
        <translation>Statuses</translation>
    </message>
    <message>
        <source>SMS</source>
        <translation>SMS</translation>
    </message>
</context>
<context>
    <name>SearchTab</name>
    <message>
        <source>Search for:</source>
        <translation>Search for:</translation>
    </message>
    <message>
        <source>Chats</source>
        <translation>Chats</translation>
    </message>
    <message>
        <source> - All chats - </source>
        <translation> - All chats - </translation>
    </message>
    <message>
        <source>Statuses</source>
        <translation>Statuses</translation>
    </message>
    <message>
        <source> - All buddies - </source>
        <translation> - All buddies - </translation>
    </message>
    <message>
        <source>Smses</source>
        <translation>Smses</translation>
    </message>
    <message>
        <source> - All recipients - </source>
        <translation> - All recipients - </translation>
    </message>
    <message>
        <source>By date</source>
        <translation>By date</translation>
    </message>
    <message>
        <source>to</source>
        <translation>to</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Search</translation>
    </message>
    <message>
        <source>Found</source>
        <translation>Found</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Buddy</source>
        <translation>Buddy</translation>
    </message>
    <message>
        <source>Recipient</source>
        <translation>Recipient</translation>
    </message>
</context>
<context>
    <name>ShowHistoryActionDescription</name>
    <message>
        <source>View Chat History</source>
        <translation>View Chat History</translation>
    </message>
    <message>
        <source>Show last %1 messages</source>
        <translation>Show last %1 messages</translation>
    </message>
    <message>
        <source>Show messages since yesterday</source>
        <translation>Show messages since yesterday</translation>
    </message>
    <message>
        <source>Show messages from last 7 days</source>
        <translation>Show messages from last 7 days</translation>
    </message>
    <message>
        <source>Show messages from last 30 days</source>
        <translation>Show messages from last 30 days</translation>
    </message>
    <message>
        <source>Show whole history</source>
        <translation>Show whole history</translation>
    </message>
</context>
</TS>
